@@ -1,4 +1,4 @@
-from criterion import NewsvendorCriterion
+from ..utils.criterion import NewsvendorCriterion
 from ..utils.validation import check_cu_co
 from ..metrics.costs import calc_avg_costs
 
